@@ -21,7 +21,7 @@ use Try::Tiny;
 
 use Data::Printer;
 
-our $VERSION='1.02';
+our $VERSION = '1.03';
 
 # no warnings 'uninitialized';
 no warnings qw/experimental/;
@@ -30,7 +30,7 @@ no warnings qw/experimental/;
 
 Vote::Count::Method::CondorcetVsIRV
 
-=head1 VERSION 1.02
+=head1 VERSION 1.03
 
 =cut
 
@@ -131,200 +131,207 @@ WriteLog behaves normally, there is a log set for the CondorcetVSIRV object as w
 
 # LogTo over-writes role LogTo changing default filename.
 has 'LogTo' => (
-  is      => 'rw',
-  isa     => 'Str',
-  default => '/tmp/condorcetvsirv',
+    is      => 'rw',
+    isa     => 'Str',
+    default => '/tmp/condorcetvsirv',
 );
 
 has 'LogRedactedTo' => (
-  is      => 'lazy',
-  is      => 'rw',
-  isa     => 'Str',
-  builder => '_setredactedlog',
+    is      => 'lazy',
+    is      => 'rw',
+    isa     => 'Str',
+    builder => '_setredactedlog',
 );
 
 sub _setredactedlog ( $self ) {
-  # There is a bug with LogTo being uninitialized despite having a default
-  my $logto =
-    defined $self->LogTo()
-    ? $self->LogTo() . '_redacted'
-    : '/tmp/condorcetvsirv_redacted';
-  return $logto;
+    # There is a bug with LogTo being uninitialized despite having a default
+    my $logto
+        = defined $self->LogTo()
+        ? $self->LogTo() . '_redacted'
+        : '/tmp/condorcetvsirv_redacted';
+    return $logto;
 }
 
 has 'TieBreakMethod' => (
-  is      => 'ro',
-  isa     => 'Str',
-  default => 'grandjunction',
+    is      => 'ro',
+    isa     => 'Str',
+    default => 'grandjunction',
 );
 
 has 'BallotSet' => ( is => 'ro', isa => 'HashRef', required => 1 );
 
 has 'Active' => (
-  is      => 'rw',
-  isa     => 'HashRef',
-  lazy    => 1,
-  builder => '_InitialActive',
+    is      => 'rw',
+    isa     => 'HashRef',
+    lazy    => 1,
+    builder => '_InitialActive',
 );
 
 sub _InitialActive ( $I ) { return dclone $I->BallotSet()->{'choices'} }
 
 sub SetActive ( $I, $active ) {
-  $I->{'Active'} = dclone $active;
-  $I->{'Election'}->SetActive($active);
-  if ( defined $I->{'RedactedElection'} ) {
-    $I->{'RedactedElection'}->SetActive($active);
-  }
+    $I->{'Active'} = dclone $active;
+    $I->{'Election'}->SetActive($active);
+    if ( defined $I->{'RedactedElection'} ) {
+        $I->{'RedactedElection'}->SetActive($active);
+    }
 }
 
 sub ResetActive ( $self ) {
-  my $new = dclone $self->BallotSet()->{'choices'};
-  $self->SetActive($new);
-  return $new;
+    my $new = dclone $self->BallotSet()->{'choices'};
+    $self->SetActive($new);
+    return $new;
 }
 
 # sub ResetActive ( $self ) { return dclone $self->BallotSet()->{'choices'} }
 
 sub _CVI_IRV ( $I, $active, $smithsetirv ) {
-  my $WonIRV    = undef;
-  my $irvresult = undef;
-  if ($smithsetirv) {
-    # smithirv needs to match irv args.
-    $irvresult = $I->SmithSetIRV( $I->TieBreakMethod() );
-  }
-  else {
-    $irvresult = $I->RunIRV( $active, $I->TieBreakMethod() );
-  }
-  return $irvresult->{'winner'} if $irvresult->{'winner'};
-  $I->logt("Aborting Election. IRV ended with a Tie.");
-  $I->logt(
-    "Active (Tied) Choices are: " . join( ', ', $irvresult->{'tied'} ) );
-  $I->SetActiveFromArrayRef( $irvresult->{'tied'} );
-  return 0;
+    my $WonIRV    = undef;
+    my $irvresult = undef;
+    if ($smithsetirv) {
+        # smithirv needs to match irv args.
+        $irvresult = $I->SmithSetIRV( $I->TieBreakMethod() );
+    }
+    else {
+        $irvresult = $I->RunIRV( $active, $I->TieBreakMethod() );
+    }
+    return $irvresult->{'winner'} if $irvresult->{'winner'};
+    $I->logt("Aborting Election. IRV ended with a Tie.");
+    $I->logt(
+        "Active (Tied) Choices are: " . join( ', ', $irvresult->{'tied'} ) );
+    $I->SetActiveFromArrayRef( $irvresult->{'tied'} );
+    return 0;
 }
 
 sub BUILD {
-  my $self = shift;
-  $self->{'Election'} = Vote::Count::Method::CondorcetIRV->new(
-    BallotSet      => $self->BallotSet(),
-    TieBreakMethod => $self->TieBreakMethod(),
-    Active         => $self->Active(),
-    BallotSetType  => 'rcv',
-    LogTo          => $self->{'LogTo'} . '_unredacted',
-  );
-  $self->{'RedactedElection'} = undef,;
+    my $self = shift;
+    $self->{'Election'} = Vote::Count::Method::CondorcetIRV->new(
+        BallotSet      => $self->BallotSet(),
+        TieBreakMethod => $self->TieBreakMethod(),
+        Active         => $self->Active(),
+        BallotSetType  => 'rcv',
+        LogTo          => $self->{'LogTo'} . '_unredacted',
+    );
+    $self->{'RedactedElection'} = undef,;
 }
 
 sub WriteAllLogs ($I) {
-  $I->WriteLog();
-  $I->Election()->WriteLog();
-  $I->RedactedElection()->WriteLog();
-  $I->Election()->PairMatrix()->WriteLog();
-  $I->RedactedElection()->PairMatrix()->WriteLog();
+    $I->WriteLog();
+    $I->Election()->WriteLog();
+    $I->RedactedElection()->WriteLog();
+    $I->Election()->PairMatrix()->WriteLog();
+    $I->RedactedElection()->PairMatrix()->WriteLog();
 }
 
 sub Election ($self) { return $self->{'Election'} }
 
 sub RedactedElection ( $self, $ballotset = undef, $active = undef ) {
-  return $self->{'RedactedElection'};
+    return $self->{'RedactedElection'};
 }
 
 sub CreateRedactedElection ( $self, $WonCondorcet, $WonIRV ) {
-  my $ballotset = RedactPair( $self->BallotSet(), $WonCondorcet, $WonIRV );
-  $self->{'RedactedElection'} = Vote::Count::Method::CondorcetIRV->new(
-    BallotSet      => $ballotset,
-    TieBreakMethod => $self->TieBreakMethod(),
-    Active         => $self->Active(),
-    BallotSetType  => 'rcv',
-    LogTo          => $self->LogRedactedTo(),
-  );
+    my $ballotset = RedactPair( $self->BallotSet(), $WonCondorcet, $WonIRV );
+    $self->{'RedactedElection'} = Vote::Count::Method::CondorcetIRV->new(
+        BallotSet      => $ballotset,
+        TieBreakMethod => $self->TieBreakMethod(),
+        Active         => $self->Active(),
+        BallotSetType  => 'rcv',
+        LogTo          => $self->LogRedactedTo(),
+    );
 }
 
 #  $I, $active, $smithsetirv
 sub _CVI_RedactRun ( $I, $WonCondorcet, $WonIRV, $active, $options ) {
-  my $smithsetirv =
-    defined $options->{'smithsetirv'} ? $options->{'smithsetirv'} : 0;
-  my $relaxed  = defined $options->{'relaxed'} ? $options->{'relaxed'} : 0;
-  my $E        = $I->Election();
-  my $R        = $I->RedactedElection();
-  my $ConfirmC = $R->PairMatrix->CondorcetWinner();
-  my $ConfirmI = _CVI_IRV( $R, $active, $smithsetirv );
-  if ( $ConfirmC eq $WonCondorcet or $ConfirmC eq $WonIRV ) {
-    $I->logt("Elected $ConfirmC, Redacted Ballots Condorcet Winner.");
-    return $ConfirmC;
-  }
-  else {
-    $ConfirmI = _CVI_IRV( $R, $active, $smithsetirv );
-    if ( $ConfirmI eq $WonCondorcet or $ConfirmI eq $WonIRV ) {
-      $I->logt("Elected $ConfirmI, Redacted Ballots IRV Winner.");
-      return $ConfirmI;
+    my $smithsetirv
+        = defined $options->{'smithsetirv'} ? $options->{'smithsetirv'} : 0;
+    my $relaxed  = defined $options->{'relaxed'} ? $options->{'relaxed'} : 0;
+    my $E        = $I->Election();
+    my $R        = $I->RedactedElection();
+    my $ConfirmC = $R->PairMatrix->CondorcetWinner();
+    my $ConfirmI = _CVI_IRV( $R, $active, $smithsetirv );
+    if ( $ConfirmC eq $WonCondorcet or $ConfirmC eq $WonIRV ) {
+        $I->logt("Elected $ConfirmC, Redacted Ballots Condorcet Winner.");
+        return $ConfirmC;
     }
-  }
-  $ConfirmC = 'NONE' unless $ConfirmC;
-  $I->logt("Neither $WonCondorcet nor $WonIRV were confirmed.");
-  $I->logt(
-    "Redacted Ballots Winners: Condorcet = $ConfirmC, IRV = $ConfirmI");
-  if ($relaxed) {
-    my $GreatestLoss = $R->PairMatrix()->GreatestLoss($WonCondorcet);
-    my $Margin =
-      $E->PairMatrix()->GetPairResult( $WonCondorcet, $WonIRV )->{'margin'};
-    $I->logt("The margin of the Condorcet over the IRV winner was: $Margin");
+    else {
+        $ConfirmI = _CVI_IRV( $R, $active, $smithsetirv );
+        if ( $ConfirmI eq $WonCondorcet or $ConfirmI eq $WonIRV ) {
+            $I->logt("Elected $ConfirmI, Redacted Ballots IRV Winner.");
+            return $ConfirmI;
+        }
+    }
+    $ConfirmC = 'NONE' unless $ConfirmC;
+    $I->logt("Neither $WonCondorcet nor $WonIRV were confirmed.");
     $I->logt(
-"$WonCondorcet\'s greatest loss with redacted ballots was $GreatestLoss."
-    );
-    if ( $Margin > $GreatestLoss ) {
-      $I->logt("Elected: $WonCondorcet");
-      return $WonCondorcet;
+        "Redacted Ballots Winners: Condorcet = $ConfirmC, IRV = $ConfirmI");
+    if ($relaxed) {
+        my $GreatestLoss = $R->PairMatrix()->GreatestLoss($WonCondorcet);
+        my $Margin = $E->PairMatrix()->GetPairResult( $WonCondorcet, $WonIRV )
+            ->{'margin'};
+        $I->logt(
+            "The margin of the Condorcet over the IRV winner was: $Margin");
+        $I->logt(
+            "$WonCondorcet\'s greatest loss with redacted ballots was $GreatestLoss."
+        );
+        if ( $Margin > $GreatestLoss ) {
+            $I->logt("Elected: $WonCondorcet");
+            return $WonCondorcet;
+        }
     }
-  }
-  $I->logt("Elected: $WonIRV");
-  return $WonIRV;
+    $I->logt("Elected: $WonIRV");
+    return $WonIRV;
 }
 
 sub CondorcetVsIRV ( $self, %args ) {
-  my $E           = $self->Election();
-  my $smithsetirv = defined $args{'smithsetirv'} ? $args{'smithsetirv'} : 0;
-  my $active      = $self->Active();
-  # check for majority winner.
-  my $majority = $E->EvaluateTopCountMajority()->{'winner'};
-  return $majority if $majority;
-  my $WonIRV       = undef;
-  my $WonCondorcet = $E->PairMatrix()->CondorcetWinner();
-  if ($WonCondorcet) {
-    $self->logt("Condorcet Winner is $WonCondorcet");
-    # Even if SmithSetIRV requested, it would return the condorcet winner
-    # We need to know if a different choice would win IRV.
-    $WonIRV = $E->RunIRV( $active, $E->TieBreakMethod() )->{'winner'};
-  }
-  else {
-    $self->logt("No Condorcet Winner");
-    $WonIRV = _CVI_IRV( $E, $active, $smithsetirv );
-    $self->logt("Electing IRV Winner $WonIRV");
-    return { 'winner' => $WonIRV };
-  }
-
-  # IRV private already logged tie, now return the false value.
-  # Edge case IRV tie with Condorcet Winner, I guess CW wins?
-  unless ($WonIRV) {
+    my $E           = $self->Election();
+    my $smithsetirv = defined $args{'smithsetirv'} ? $args{'smithsetirv'} : 0;
+    my $active      = $self->Active();
+    # check for majority winner.
+    my $majority = $E->EvaluateTopCountMajority()->{'winner'};
+    return $majority if $majority;
+    my $WonIRV       = undef;
+    my $WonCondorcet = $E->PairMatrix()->CondorcetWinner();
     if ($WonCondorcet) {
-      $self->logt("Electing Condorcet Winner $WonCondorcet, IRV tied.");
-      return $WonCondorcet;
+        $self->logt("Condorcet Winner is $WonCondorcet");
+        # Even if SmithSetIRV requested, it would return the condorcet winner
+        # We need to know if a different choice would win IRV.
+        $WonIRV = $E->RunIRV( $active, $E->TieBreakMethod() )->{'winner'};
     }
-    return { 'winner' => 0 };
-  }
-  if ( $WonIRV eq $WonCondorcet ) {
-    $self->logt("Electing $WonIRV the winner by both Condorcet and IRV.");
-    return { 'winner' => $WonIRV };
-  }
-  if ( $WonIRV and !$WonCondorcet ) {
-    $self->logt(
-      "Electing IRV Winner $WonIRV. There was no Condorcet Winner.");
-    return { 'winner' => $WonIRV };
-  }
-  $self->CreateRedactedElection( $WonCondorcet, $WonIRV );
-  my $winner =
-    $self->_CVI_RedactRun( $WonCondorcet, $WonIRV, $active, \%args );
-  return { 'winner' => $winner };
+    else {
+        $self->logt("No Condorcet Winner");
+        $WonIRV = _CVI_IRV( $E, $active, $smithsetirv );
+        if ($WonIRV) {
+            $self->logt("Electing IRV Winner $WonIRV");
+            return { 'winner' => $WonIRV };
+        }
+        else {
+            $self->logt("IRV and Condorcet Tied, No Winner.");
+            return { 'winner' => 0 };
+        }
+    }
+
+    # IRV private already logged tie, now return the false value.
+    # Edge case IRV tie with Condorcet Winner, I guess CW wins?
+    unless ($WonIRV) {
+        if ($WonCondorcet) {
+            $self->logt("Electing Condorcet Winner $WonCondorcet, IRV tied.");
+            return { 'winner' => $WonCondorcet};
+        }
+        return { 'winner' => 0 };
+    }
+    if ( $WonIRV eq $WonCondorcet ) {
+        $self->logt("Electing $WonIRV the winner by both Condorcet and IRV.");
+        return { 'winner' => $WonIRV };
+    }
+    if ( $WonIRV and !$WonCondorcet ) {
+        $self->logt(
+            "Electing IRV Winner $WonIRV. There was no Condorcet Winner.");
+        return { 'winner' => $WonIRV };
+    }
+    $self->CreateRedactedElection( $WonCondorcet, $WonIRV );
+    my $winner
+        = $self->_CVI_RedactRun( $WonCondorcet, $WonIRV, $active, \%args );
+    return { 'winner' => $winner };
 
 }
 
